@@ -20,10 +20,17 @@ class tables(Enum):
     clean_commits_with_structure="1XFbhSXuKFKQxFaYx_x__314Vja6DKCf_"
     clean_commits_with_structure_v2="12QMCdj5RPPdOaNcbiF3VRnIvHEzxFnBj"
     commits_with_scores_v2="10Gwj-ZETuFhm0Uxvtzh2XOiitfvqz9mK"
-
+    refactoring_placeholders_v1="1S1Yg4gc4qoSBDqnlCnbYzWWHVdUFzfZf"
+    clean_commits_no_placeholders_v5="1Hb0PJU8Po5HjA5uHf9g5AmOBfsFzP-Ck"
+    clean_commits_with_placeholders_v5="1rYddSixXI8e4pc-9yEgo7HMbYDhhgmT5"
+    #LDA_commits_v5="1svYVbYws8cT0CivKQZmJJCNgBgXb-XRQ"
+    LDA_commits_v5="1VvPzNK3lsU-c-FeHMtkKiHOzK7hoFHvd" # Better topics
+    clean_commits_with_structure_v5_no_stanza="1626BaQsVUHagNEuU2sk700CPqzMSLe-_"
+    clean_commits_with_structure_v5_with_stanza="1cTX8DvVvgyVmvV5XXg4AAu9G14evnmfI"
+    commits_with_scores_v5="1VCynAbQ0Vo-kUskvZdtHWxAnZiw4BWs6"
 
 def load_dataset(table):
-    url = f"https://drive.google.com/u/0/uc?id={table.value}&export=download"
-    file = requests.get(url).content
-    dataset = pd.read_csv(BytesIO(file))
+    file_id = table if type(table) == str else table.value
+    file = Drive().authenticate().download_file(file_id)
+    dataset = pd.read_csv(StringIO(file))
     return dataset
